@@ -5,6 +5,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import argparse
 import bz2
 import datetime
 import os
@@ -18,7 +19,7 @@ import pwndbg.regs
 from pwndbg.gdbutils.functions import GdbFunction
 
 
-@pwndbg.commands.ParsedCommand
+@pwndbg.commands.ArgparsedCommand("Synchronize IDA's cursor with GDB")
 @pwndbg.commands.OnlyWhenRunning
 @pwndbg.events.stop
 @pwndbg.ida.withIDA
@@ -33,8 +34,13 @@ def j(*args):
         pass
 
 
-
-@pwndbg.commands.Command
+parser = argparse.ArgumentParser()
+parser.description = """
+    Select and print stack frame that called this one.
+    An argument says how many frames up to go.
+    """
+parser.add_argument("n", nargs="?", default=1, type=int, help="The number of stack frames to go up.") 
+@pwndbg.commands.ArgparsedCommand(parser)
 @pwndbg.commands.OnlyWhenRunning
 def up(n=1):
     """
@@ -48,13 +54,21 @@ def up(n=1):
             f = f.older()
     f.select()
 
+    # workaround for #632
+    gdb.execute('frame', to_string=True)
+
     bt = pwndbg.commands.context.context_backtrace(with_banner=False)
     print('\n'.join(bt))
 
     j()
 
-
-@pwndbg.commands.Command
+parser = argparse.ArgumentParser()
+parser.description = """
+    Select and print stack frame called by this one.
+    An argument says how many frames down to go.
+    """
+parser.add_argument("n", nargs="?", default=1, type=int, help="The number of stack frames to go down.") 
+@pwndbg.commands.ArgparsedCommand(parser)
 @pwndbg.commands.OnlyWhenRunning
 def down(n=1):
     """
@@ -68,13 +82,16 @@ def down(n=1):
             f = f.newer()
     f.select()
 
+    # workaround for #632
+    gdb.execute('frame', to_string=True)
+
     bt = pwndbg.commands.context.context_backtrace(with_banner=False)
     print('\n'.join(bt))
 
     j()
 
 
-@pwndbg.commands.Command
+@pwndbg.commands.ArgparsedCommand("Save the ida database.")
 @pwndbg.ida.withIDA
 def save_ida():
     """Save the IDA database"""
