@@ -43,13 +43,13 @@ def rreload(module, mdict=None):
         pass
 
 
-@pwndbg.commands.Command
+@pwndbg.commands.ArgparsedCommand("Reload pwndbg.")
 def reload(*a):
     pwndbg.events.on_reload()
     rreload(pwndbg)
     pwndbg.events.after_reload()
 
-@pwndbg.commands.Command
+@pwndbg.commands.ArgparsedCommand("Makes pwndbg reinitialize all state.")
 def reinit_pwndbg():
     """
     Makes pwndbg reinitialize all state.
