@@ -23,7 +23,7 @@ parser.add_argument('argument', nargs='*', type=str,
                     help='Arguments to pass to ROPgadget')
 
 
-@pwndbg.commands.ArgparsedCommand(parser)
+@pwndbg.commands.ArgparsedCommand(parser, aliases=["ropgadget"])
 @pwndbg.commands.OnlyWithFile
 def rop(grep, argument):
     with tempfile.NamedTemporaryFile() as corefile:
@@ -58,7 +58,3 @@ def rop(grep, argument):
         for line in stdout.splitlines():
             if re.search(grep, line):
                 print(line)
-
-@pwndbg.commands.Command
-def ropgadget(*a):
-    return rop(*a)
