@@ -14,7 +14,7 @@ import gdb
 import pwndbg.memoize
 
 
-@pwndbg.memoize.reset_on_exit
+@pwndbg.memoize.reset_on_objfile
 def is_remote():
     # Example:
     # pwndbg> maintenance print target-stack
