@@ -5,32 +5,32 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-import subprocess
 from re import search
 from subprocess import STDOUT
+from subprocess import CalledProcessError
 
 import pwndbg.commands
 import pwndbg.memoize
 import pwndbg.wrappers
 
 cmd_name = "checksec"
+cmd_pwntools = ["pwn", "checksec"]
 
-@pwndbg.wrappers.OnlyWithCommand(cmd_name)
+@pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
 @pwndbg.memoize.reset_on_objfile
 def get_raw_out():
     local_path = pwndbg.file.get_file(pwndbg.proc.exe)
     try:
-        version_output = subprocess.check_output([get_raw_out.cmd_path, "--version"], stderr=STDOUT).decode('utf-8')
-        match = search('checksec v([\\w.]+),', version_output)
-        if match:
-            version = tuple(map(int, (match.group(1).split("."))))
-            if version >= (2, 0):
-                return pwndbg.wrappers.call_cmd([get_raw_out.cmd_path, "--file=" + local_path])
-    except Exception:
+        return pwndbg.wrappers.call_cmd(get_raw_out.cmd + ["--file=" + local_path])
+    except CalledProcessError:
         pass
-    return pwndbg.wrappers.call_cmd([get_raw_out.cmd_path, "--file", local_path])
+    try:
+        return pwndbg.wrappers.call_cmd(get_raw_out.cmd + ["--file", local_path])
+    except CalledProcessError:
+        pass
+    return pwndbg.wrappers.call_cmd(get_raw_out.cmd + [local_path])
 
-@pwndbg.wrappers.OnlyWithCommand(cmd_name)
+@pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
 def relro_status():
     relro = "No RELRO"
     out = get_raw_out()
@@ -42,7 +42,7 @@ def relro_status():
 
     return relro
 
-@pwndbg.wrappers.OnlyWithCommand(cmd_name)
+@pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
 def pie_status():
     pie = "No PIE"
     out = get_raw_out()
